**************************************************** 
****************************************************
** TABLES FOR THE PAPER: "CORRUPTION AND FIRMS"
****************************************************
****************************************************

clear all 
set more off
set maxvar 30000
cap log close
set seed 1111


// Path: Write the path to the replication folder
	global path "~/Dropbox/Research"	
	
// Subfolders
	global Data 	"${path}Data/"	
	global Tables 	"${path}Tables/"
	global Figures 	"${path}Figures/"
	
// Folder for tables
	cd "${Tables}"	
	
********************************************************************************
** MAIN PAPER
********************************************************************************	
	
************	
// Table 1. Summary Statistics: Local Economy
************
	
	* Panel A: Eligible municipalities	
	* Load dataset 
	use "${Data}/Data_Quarterly.dta", clear
	
	tabstat nplants_priv nfirms_priv emp_priv avg_pay_priv emp_pub avg_pay_pub nplants_PSc4_e50pt1 nplants_CSc4_50pNt1, c(s) s(mean sd p10 p50 p90) format(%10.2f)
	
	* Load dataset
	use "${Data}/Data_Yearly.dta", clear
	
	tabstat GDP_pc TotalCredit, c(s) s(mean sd p10 p50 p90) format(%10.2f)

	
	* Panel B: Audited municipalities
	* Load dataset 
	use "${Data}/Data_Quarterly.dta", clear
	
	keep if EverAuditedMunicipality == 1
	tabstat nplants_priv nfirms_priv emp_priv avg_pay_priv emp_pub avg_pay_pub nplants_PSc4_e50pt1 nplants_CSc4_50pNt1, c(s) s(mean sd p10 p50 p90) format(%10.2f)	
	
	* Load dataset
	use "${Data}/Data_Yearly.dta", clear
	
	keep if EverAuditedMunicipality == 1
	tabstat GDP_pc TotalCredit, c(s) s(mean sd p10 p50 p90) format(%10.2f)
	
	
	
************
// Table 2. Are Audits Random?
************
	* Load dataset
	use "${Data}/Data_Yearly.dta", clear
	
	global RAIS 	"ln_emp_priv nplants_priv avg_size sh_SmallEmp sh_MedEmp sh_manuf sh_services sh_retail sh_construction"
	global PUBSEC	"ln_emp_pub sh_pub "	
	global AGG 		"population lnGDP_w1 Sh_Inf_Emp_Census gini_2000 Iliteracy_2000 Educ_Distmorethan8_2000"
	
	* Column 1
	areg EverAuditedMunicipality $RAIS $PUBSEC $AGG , abs(UF) r
	sum EverAuditedMunicipality
	outreg2 using Table_2, tex(frag) replace label bdec(3) addtext(Region FE, Yes) nocons keep($RAIS $PUBSEC $AGG) adds(Mean DV, r(mean)) 							

	* Load dataset
	use "${Data}/Data_Yearly.dta", clear
	
	* Column 2
	areg Audited2003_05 $RAIS $PUBSEC $AGG Opposition if (Audited2003_05 == 1 | EverAuditedMunicipality == 0) & year == 2002,  r abs(UF)
	sum Audited2003_05 if e(sample) == 1
	outreg2 using Table_2, tex(frag) append label bdec(3) addtext(Region FE, Yes) nocons keep($RAIS $PUBSEC $AGG Opposition) adds(Mean DV, r(mean)) 							
	
	* Column 3
	areg Audited2006_08 $RAIS $PUBSEC $AGG Opposition if (Audited2006_08 == 1 | EverAuditedMunicipality == 0) & year == 2005, r abs(UF)
	sum Audited2006_08 if e(sample) == 1
	outreg2 using Table_2, tex(frag) append label bdec(3) addtext(Region FE, Yes) nocons keep($RAIS $PUBSEC $AGG Opposition) adds(Mean DV, r(mean)) 							
	
	* Column 4
	areg Audited2009_11 $RAIS $PUBSEC $AGG Opposition if (Audited2009_11 == 1 | EverAuditedMunicipality == 0) & year == 2008 , r abs(UF)
	sum Audited2009_11 if e(sample) == 1
	outreg2 using Table_2, tex(frag) append label bdec(3) addtext(Region FE, Yes) nocons keep($RAIS $PUBSEC $AGG Opposition) adds(Mean DV, r(mean)) 							

	* Column 5
	areg Audited2012_14 $RAIS $PUBSEC $AGG Opposition if (Audited2012_14 == 1 | EverAuditedMunicipality == 0) & year == 2011,  r abs(UF)
	sum Audited2012_14 if e(sample) == 1
	outreg2 using Table_2, tex(frag) append label bdec(3) addtext(Region FE, Yes) nocons keep($RAIS $PUBSEC $AGG Opposition) adds(Mean DV, r(mean)) 							
	
************	
// Table 3. The Impact of Anti-corruption Audits on Firms
************
	* Load dataset
	use "${Data}/Data_Quarterly.dta", clear

	global Outcome	"ln_nplants_priv_w1 ln_nfirms_priv_w1 ln_nplants_PSc4_e50pt1_w1 ln_un_firms_PSc4_e50pt1_w1 ln_nplants_PSc4_e50pt0_w1 ln_un_firms_PSc4_e50pt0_w1 ln_nplants_CSc4_50pNt1_w1 ln_un_firms_CSc4_50pNt1_w1 ln_nplants_CSc4_50pNt0_w1 ln_un_firms_CSc4_50pNt0_w1"	

	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'  Post_Audited  if year >= 2001 & t >= -4 & t <= 12 , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_3 , tex(frag) bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}	
	
************	
// Table 4. The Impact of Audits on Other Measures of Economic Activity
************

	*** PAC and PAS: Columns 1 and 2
	use "${Data}/Data_Yearly.dta", clear

	global Outcome	"ln_SalesPACPAS_w1 ln_InvestmenPACPAS_w1"	
	
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if  year >= 2001 & t >= -1 & t <= 3, abs(municipio year ) cluster(municipio)	
			sum `i' if e(sample) == 1 & t < 0, d
			outreg2 using Table_4 , tex(frag) bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
			local replace append
	}
	
	* Load dataset
	use "${Data}/Data_Yearly.dta", clear

	global Outcome	"ln_TotalCredit_w1 ln_TotalDeposits_w1"	

	*** Columns 3 and 4
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if  year >= 2001 & t >= -1 & t <= 3, abs(municipio year ) cluster(municipio)	
			sum `i' if e(sample) == 1 & t < 0, d
			outreg2 using Table_4 , tex(frag) bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
			local replace append
	}
	
************	
// Table 5. Direct Effects and Political Incentives
************	
	* Load dataset
	use "${Data}/Data_Quarterly.dta", clear

	global Outcome	"ln_nfirms_priv_w1 ln_un_firms_PSc4_e50pt1_w1 ln_un_firms_PSc4_e50pt0_w1  ln_un_firms_CSc4_50pNt1_w1 ln_un_firms_CSc4_50pNt0_w1"	
	
	* Panel A: Early years		
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if year >= 2001 & t >= -4 & t <= 12 & (EarlyYOE == 1 | EverAuditedMunicipality == 0) , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_5A , tex(frag)   bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}				

	* Panel B: Final years
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if year >= 2001 & t >= -4 & t <= 12 & (LateYOE == 1 | EverAuditedMunicipality == 0) , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_5B , tex(frag)   bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}	
	
	* Panel C: First term
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if year >= 2001 & t >= -4 & t <= 12 & (Audited1stTermMayor == 1 | EverAuditedMunicipality == 0) , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_5C , tex(frag)   bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}	
	
	* Panel D: Second term
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if year >= 2001 & t >= -4 & t <= 12 & (Audited2ndTermMayor == 1 | EverAuditedMunicipality == 0) , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_5D , tex(frag)   bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}	

************	
// Table 6. Indirect Effects: Estimating Deterrence via Spillovers
************
	* Load dataset
	use "${Data}/Data_Quarterly.dta", clear

	global Outcome	"ln_nfirms_priv_w1 ln_un_firms_PSc4_e50pt1_w1 ln_un_firms_PSc4_e50pt0_w1  ln_un_firms_CSc4_50pNt1_w1 ln_un_firms_CSc4_50pNt0_w1"	

	* Panel A: Spillover effects
	label var AuditedMicroreg 		"PostAudit"
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'  AuditedMicroreg  if year >= 2001 & tmr >= -4 & tmr <= 12 & EverAuditedMunicipality != 1 , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_6A , tex(frag)   bdec(3) nocons label `replace' keep(AuditedMicroreg) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
		local replace append
	}	

	* Panel B: Excluding spillover effects
	local replace replace			
	foreach i in $Outcome {	
		reghdfe `i'   Post_Audited  if year >= 2001 & t >= -4 & t <= 12 & EverAudMR != 1 , abs(municipio time ) cluster(municipio)	
		sum `i' if e(sample) == 1 & t <= 0, d
		outreg2 using Table_6B , tex(frag) bdec(3) nocons label `replace' keep(Post_Audited) addtext(Municipality FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd))
			local replace append
	}	

************
// Table 7. Anti-corruption Multipliers and Cost-Benefit Analysis
************
	** Overall
	* Value Added - WOID: Multiplier
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local v 96000	/* Value added from WOID as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'
	
	* Value Added - IBGE: Multiplier
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local v 71000	/* Value added from IBGE as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'

	* Formula from CR-CPS (2019): Multiplier
	local e 0.333 	/* Capital share: Corbi et al (2018) page 22 */
	local h 0.12 	/* Elasticity of hours: Corbi et al (2018) page 22 */
	local o 35136 	/* Output over employment: Corbi et al (2018) page 22 and converted to USD */
	
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local s 3.88	/* Average size of entrant from RAIS*/
	
	di (1-`e') * (1+`h') * `o' * `a' * `n' * `s' / `l'
	
	* Value Added - WOID: Cost-Benefit
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local v 96000	/* Value added from WOID as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'
	
	* Value Added - IBGE: Cost-Benefit
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local v 71000	/* Value added from IBGE as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'

	* Formula from CR-CPS (2019): Cost-Benefit
	local e 0.333 	/* Capital share: Corbi et al (2018) page 22 */
	local h 0.12 	/* Elasticity of hours: Corbi et al (2018) page 22 */
	local o 35136 	/* Output over employment: Corbi et al (2018) page 22 and converted to USD */
	
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.009 	/* Increase in number of firms from Table 3*/
	local s 3.88	/* Average size of entrant from RAIS*/
	
	di (1-`e') * (1+`h') * `o' * `a' * `n' * `s' / `l'	
	
	
	** Accounting for Spillovers
	* Value Added - WOID: Multiplier
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local v 96000	/* Value added from WOID as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'
	
	* Value Added - IBGE: Multiplier
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local v 71000	/* Value added from IBGE as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'

	* Formula from CR-CPS (2019): Multiplier
	local e 0.333 	/* Capital share: Corbi et al (2018) page 22 */
	local h 0.12 	/* Elasticity of hours: Corbi et al (2018) page 22 */
	local o 35136 	/* Output over employment: Corbi et al (2018) page 22 and converted to USD */
	
	local l 110000 	/* Less money stolen from Avis et al (2017 JPE) */
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local s 3.88	/* Average size of entrant from RAIS*/
	
	di (1-`e') * (1+`h') * `o' * `a' * `n' * `s' / `l'
	
	* Value Added - WOID: Cost-Benefit
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local v 96000	/* Value added from WOID as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'
	
	* Value Added - IBGE: Cost-Benefit
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local v 71000	/* Value added from IBGE as explain inn section 5.4 of the paper */
	
	di `a' * `n' * `v' / `l'

	* Formula from CR-CPS (2019): Cost-Benefit
	local e 0.333 	/* Capital share: Corbi et al (2018) page 22 */
	local h 0.12 	/* Elasticity of hours: Corbi et al (2018) page 22 */
	local o 35136 	/* Output over employment: Corbi et al (2018) page 22 and converted to USD */
	
	local l 50000 	/* Direct cost of CGU audit Zamboni and Litschig (2018) */
	local a 251.11 	/* Average number of firms from Table 1 */
	local n 0.022 	/* Increase in number of firms from Table 6 Panel B*/
	local s 3.88	/* Average size of entrant from RAIS*/
	
	di (1-`e') * (1+`h') * `o' * `a' * `n' * `s' / `l'	
	
	
************
// Table 8. Heterogeneity Across Local Firms
************	

	use "${Data}/Data_Firms.dta", clear

	global Het1 "PSC4_50P_ever CSc4_p50N freceitaP mreceitaP mpoliticianP mcandidateP maffiliatedP"
	global Het2 "Inc"
	
	foreach h in $Het1 $Het2 {
		replace `h' = 0 if `h' == .
		cap g PAud_`h' = Post_Audited * `h'
	}
	
	foreach h in $Het1 {
		foreach h2 in $Het2 {
			cap g PAud_`h'_`h2' = Post_Audited * `h' * `h2'
			}	
		}
	}
	
	local replace replace			
	foreach h in $Het1 {
		foreach h2 in $Het2 {
			rename PAud_`h' 		PAud_Z
			rename PAud_`h2' 		PAud_Z2
			rename PAud_`h'_`h2'	PAud_Z_Z2
			label var PAud_Z_Z2 	"PostAudit $\times$ Incumbent $\times$ Z"
			label var PAud_Z 		"PostAudit $\times$ Z"
			label var PAud_Z2 		"PostAudit $\times$ Incumbent"	
			
			reghdfe ln_emp_w1 PAud_Z_Z2 PAud_Z PAud_Z2 Post_Audited  if year >= 2001 & t >= -4 & t <= 12 , abs(IDPlant time) cluster(municipio)	
			test _b[PAud_Z_Z2] + _b[PAud_Z] + _b[PAud_Z2] + _b[Post_Audited] = 0
			local pval = `r(p)'
			sum `i' if e(sample) == 1 & t <= 0, d
			outreg2 using Table_8 , tex(frag) bdec(3) nocons label `replace' keep(PAud_Z_Z2 PAud_Z PAud_Z2 Post_Audited) addtext(Establishment FE, Yes, Year-quarter FE, Yes) adds(Avg Dep Var, r(mean), SD Dep Var, r(sd), Test sum coeff, `pval')
			local replace append
				
			rename PAud_Z 		PAud_`h' 
			rename PAud_Z2 		PAud_`h2' 
			rename PAud_Z_Z2 	PAud_`h'_`h2' 										
		}				
	}	

